import { Directive, ElementRef, forwardRef, HostListener, Input, ChangeDetectorRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { MAT_INPUT_VALUE_ACCESSOR } from '@angular/material/input';
import { numberFormat } from './helpers';

@Directive({
    selector: 'input[matInputNumber]',
    providers: [
        { provide: MAT_INPUT_VALUE_ACCESSOR, useExisting: MatInputNumberDirective },
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => MatInputNumberDirective),
            multi: true,
        }
    ]
})
export class MatInputNumberDirective {
    // tslint:disable-next-line:variable-name
    private _value: string | null;
    private isUpdate: boolean = false;

    constructor(private elementRef: ElementRef<HTMLInputElement>,
        private cd: ChangeDetectorRef) {

    }

    get value(): string | null {
        return this._value;
    }

    set value(value: string | null) {
        this._value = value;
        this._onChange(value);
        this._onTouched();
        this.cd.detectChanges();
        this.displayValue(value);
    }

    private formatValue(value: string | null) {
        let min = parseFloat(this.elementRef.nativeElement.min);
        let max = parseFloat(this.elementRef.nativeElement.max);
        let formattedValue: string = numberFormat(value);

        this.isUpdate = false;

        if (value) {
            if (this.elementRef.nativeElement.hasAttribute("maxLength") && formattedValue.length > this.elementRef.nativeElement.maxLength) {
                formattedValue = formattedValue.substring(0, this.elementRef.nativeElement.maxLength);
                this.isUpdate = true;
            }

            if (!isNaN(min) && min > parseFloat(formattedValue)) {
                formattedValue = min.toString() || null;
                this.isUpdate = true;
            }

            if (!isNaN(max) && max < parseFloat(formattedValue)) {
                formattedValue = max.toString() || null;
                this.isUpdate = true;
            }
        }

        if (formattedValue !== null) {
            this.elementRef.nativeElement.value = formattedValue;
        } else {
            this.elementRef.nativeElement.value = '';
        }

        if (this.isUpdate) {
            this.value = formattedValue;
        }
    }

    private displayValue(value) {
        let formattedValue: string = numberFormat(value);
        if (formattedValue !== null) {
            this.elementRef.nativeElement.value = formattedValue;
        } else {
            this.elementRef.nativeElement.value = '';
        }
    }

    // private unFormatValue() {
    //     const value = this.elementRef.nativeElement.value;
    //     this._value = value.replace(/[^\d.-]/g, '');
    //     if (value) {
    //         this.elementRef.nativeElement.value = this._value;
    //     } else {
    //         this.elementRef.nativeElement.value = '';
    //     }
    // }

    @HostListener('input', ['$event.target.value'])
    onInput(value) {
        this._value = value.replace(/[^\d.-]/g, '');
        this._onChange(this._value); // here to notify Angular Validators
    }

    @HostListener('blur')
    _onBlur() {
        this.formatValue(this._value);
    }

    // @HostListener('focus')
    // onFocus() {
    //     this.unFormatValue();
    // }

    _onChange(value: any): void {
    }

    _onTouched(): void {
    }

    writeValue(value: any) {
        this.value = value;
        this.displayValue(value); // format Value
    }

    registerOnChange(fn: (value: any) => void) {
        this._onChange = fn;
    }

    registerOnTouched(fn: () => void) {
        this._onTouched = fn;
    }

}