import { ViewContainerRef, Injectable } from "@angular/core";
import { AlertModalComponent } from '../components/shared/modal/alert-modal.component';
import { MatDialog } from '@angular/material/dialog';
import { InfoModalComponent } from '../components/shared/modal/info-modal.component';
import { WarnModalComponent } from '../components/shared/modal/warn-modal.component';
import { ConfirmModalComponent } from '../components/shared/modal/confirm-modal.component';


class ModalOptions {
    public height?: string;
    public width?: string
}

@Injectable()
export class ModalService {

    constructor(
        private dialog: MatDialog
    ) { }
    
    private modalWidth: string = "30rem";
    private modalHeight: string = "16rem";

    info(data: string, viewRef: ViewContainerRef, fn?: Function, option?: ModalOptions) {
        const dialogRef = this.dialog.open(
            InfoModalComponent,
            {
                panelClass: 'modal-dialog-panel',
                autoFocus: true,
                width: option?.width || this.modalWidth,
                height: option?.height || this.modalHeight,
                viewContainerRef: viewRef,
                data: {
                    text: data,
                    actionButtons: [
                        {
                            text: "OK",
                            color: "primary",
                            onAction: () => {
                                (fn) ? fn() : null;

                                return true;
                            }
                        }
                    ]
                }
            })
    }

    warning(data: string, viewRef: ViewContainerRef, fn?: Function, option?: ModalOptions) {
        const dialogRef = this.dialog.open(
            WarnModalComponent,
            {
                panelClass: 'modal-dialog-panel',
                autoFocus: true,
                width: option?.width || this.modalWidth,
                height: option?.height || this.modalHeight,
                viewContainerRef: viewRef,
                data: {
                    text: data,
                    actionButtons: [
                        {
                            text: "OK",
                            color: "primary",
                            onAction: () => {
                                (fn) ? fn() : null;

                                return true;
                            }
                        }
                    ]
                }
            })
    }

    error(data: string, viewRef: ViewContainerRef, fn?: Function, option?: ModalOptions) {
        
        const dialogRef = this.dialog.open(
            AlertModalComponent,
            {
                panelClass: 'modal-dialog-panel',
                autoFocus: true,
                width: option?.width || this.modalWidth,
                height: option?.height || this.modalHeight,
                viewContainerRef: viewRef,
                data: {
                    text: data,
                    actionButtons: [
                        {
                            text: "OK",
                            color: "primary",
                            onAction: () => {
                                (fn) ? fn() : null;

                                return true;
                            }
                        }
                    ]
                }
            })
    }

    confirm(data: string, viewRef: ViewContainerRef, fnYes?: Function, fnNo?: Function, option?: ModalOptions) {

        const dialogRef = this.dialog.open(
            ConfirmModalComponent,
            {
                panelClass: 'modal-dialog-panel',
                autoFocus: true,
                width: option?.width || this.modalWidth,
                height: option?.height || this.modalHeight,
                viewContainerRef: viewRef,
                data: {
                    text: data,
                    actionButtons: [
                        {
                            text: "Yes",
                            color: "primary",
                            onAction: () => {
                                (fnYes) ? fnYes() : null;

                                return true;
                            }
                        },
                        {
                            text: "No",
                            color: "default",
                            onAction: () => {
                                (fnNo) ? fnNo() : null;

                                return true;
                            }
                        }
                    ]
                }
            })
    }
}