import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { HttpClientModule } from '@angular/common/http';
import { ReactiveFormsModule, FormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { SharedComponentModule } from '../shared/shared-component.module';
import { AuthGuard } from 'src/app/core/auth-guard.service';
import { MaterialImportModule } from '../shared/material.module';
import { RoleResolver } from 'src/app/core/role-resolver.service';
import { TechnicalComponent } from 'src/app/pages/technical/technical.component';
import { SNM008PComponent } from 'src/app/pages/technical/SNM008P/SNM008P.component';
import { SNM009PComponent } from 'src/app/pages/technical/SNM009P/SNM009P.component';
import { SNSQ030Component } from 'src/app/pages/technical/SNSQ030/SNSQ030.component';
import { SNM010PComponent } from 'src/app/pages/technical/SNM010P/SNM010P.component';
import { SNM039PComponent } from 'src/app/pages/technical/SNM039P/SNM039P.component';
import { SNM054PComponent } from 'src/app/pages/technical/SNM054P/SNM054P.component';
import { SNSQ031Component } from 'src/app/pages/technical/SNSQ031/SNSQ031.component';
import { SNSQ032Component } from 'src/app/pages/technical/SNSQ032/SNSQ032.component';
import { SNSQ038Component } from 'src/app/pages/technical/SNSQ038/SNSQ038.component';
import { SNSE143F2Component } from 'src/app/pages/technical/SNSE143_F2/SNSE143_F2.component';
import { SNM105PComponent } from 'src/app/pages/technical/SNM105P/SNM105P.component';
import { SNM041PComponent } from 'src/app/pages/technical/SNM041P/SNM041P.component';
import { SNSE165Component } from 'src/app/pages/technical/SNSE165/SNSE165.component';
import { SNSE127_1Component } from 'src/app/pages/technical/SNSE127_1/SNSE127_1.component';
import { SNM038PComponent } from 'src/app/pages/technical/SNM038P/SNM038P.component';
import { SNM034PComponent } from 'src/app/pages/technical/SNM034P/SNM034P.component';
import { SNM115PComponent } from 'src/app/pages/technical/SNM115P/SNM115P.component';

@NgModule({
  declarations: [
    TechnicalComponent,
    SNM008PComponent,
    SNM009PComponent,
    SNSQ030Component,
    SNM010PComponent,
    SNM039PComponent,
    SNSQ031Component,
    SNSQ032Component,
    SNSQ038Component,
    SNSE143F2Component,
    SNM105PComponent,
    SNM041PComponent,
    SNSE165Component,
    SNSE127_1Component,
    SNM038PComponent,
    SNM034PComponent,
    SNM115PComponent,
    SNM054PComponent
    
  ],
  imports: [
    CommonModule,
    HttpClientModule,
    FormsModule,
    ReactiveFormsModule,
    SharedComponentModule,
    FormsModule,

    //Material imports
    MaterialImportModule,

    RouterModule.forChild([
      {
        path: '',
        component: TechnicalComponent,
        children: [
          {
            path : 'SNM115P',
            component : SNM115PComponent,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNM034P',
            component : SNM034PComponent,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNM038P',
            component : SNM038PComponent,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNSE127_1',
            component : SNSE127_1Component,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNSQ038',
            component : SNSQ038Component,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path: 'SNM008P',
            component: SNM008PComponent,
            resolve: {
                role: RoleResolver
            },
          },
          {
            path : 'SNM009P',
            component : SNM009PComponent,
            resolve:{
              role: RoleResolver
            }
          },
          {
            path : 'SNSQ030',
            component : SNSQ030Component,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNM010P',
            component : SNM010PComponent,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNSQ031',
            component : SNSQ031Component,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path: 'SNM039P',
            component : SNM039PComponent,
            resolve: {
              role: RoleResolver
            }
          },
          {
            path: 'SNM054P',
            component: SNM054PComponent,
            resolve: {
              role: RoleResolver
            }
          },
          {
            path : 'SNSQ032',
            component : SNSQ032Component,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path: 'SNSE143_F2',
            component: SNSE143F2Component,
            resolve: {
              role: RoleResolver
            }
          },
          {
            path : 'SNM105P',
            component : SNM105PComponent,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNM041P',
            component : SNM041PComponent,
            resolve:{
              role : RoleResolver
            }
          },
          {
            path : 'SNSE165',
            component : SNSE165Component,
            resolve:{
              role : RoleResolver
            }
          }
         
        ],
        canActivate: [AuthGuard]
      }
    ])
  ],
  exports: [],
  providers: [AuthGuard, RoleResolver],
})
export class TechnicalModule { }

