import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';

@Component({
  selector: 'snm029p',
  templateUrl: './SNM029P.component.html',
  styleUrls: ['./SNM029P.component.css']
})



export class SNM029PComponent implements OnInit {
  public params = {
    SALESMAN_CODE: null
  }
  public data: any = {
    COMPANY_CODE:null,
    SALESMAN_CODE: null,
    SALESMAN_NAME: null,
    SALESMAN_ADDR1: null,
    SALESMAN_ADDR2: null,
    SALESMAN_ADDR3: null,
    SALESMAN_ADDR4: null,
    SMC_CONTACT: null,
    ENABLE_DATE: null,
    DISABLE_DATE: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    LAST_UPD_PGM: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    ATTRIBUTE1: null,
    ATTRIBUTE2: null,
    ATTRIBUTE3: null,
    ATTRIBUTE4: null,
    ATTRIBUTE5: null,
    UPDATE_BY_NAME:null
  };
  public ConfigRate: any = {
    ColName: "LOOKUP_SALES",
    PlaceholderText: "Select Sales",
    SourceController: "AC",
    SourceMethodName: "SNM029P_Get_Sales_man",
    NoOfShowRecords: 30,
    MinLengthSearch:0,
    UpperCase: false
  }
  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }
  
  @ViewChild("dialogMain", { static: false }) dialogMain: any;

  public MainDatatable: any = [];
  public tableData: any = [];
  public tableDataType: any = [];
  public tableDataCurr: any = [];
  public FrmTitle: any;
  public IsEdit: any = true;
  public hideCols: Array<string> = [];
  public RoleCHG : boolean = false;
  ngOnInit() {

    this.InitData();
    this.SearchForAc();
  }

  SearchForAc = () => {
    this.http.get('AC', 'SNM029P_Get_Sales_man', this.params.SALESMAN_CODE,"30")
      .subscribe(res => {
        this.MainDatatable = res.Table;
      })
  }

  onKey(evt) {
    evt.target.value =  evt.target.value.toUpperCase()
  }
   
  getDateParam(P_data) {
    if (P_data !== null && P_data != undefined) {
      let dt = new Date(P_data);
      let year = dt.getFullYear();
      let month = (1 + dt.getMonth()).toString().padStart(2, '0');
      let day = dt.getDate().toString().padStart(2, '0');
      var p_Date = year + '-' + month + '-' + day;
      return p_Date;
    } else {
      return null;
    }
  }


  InitData() {
    //this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
    this.global.GetRoleDetail().CHG === "N" ? this.RoleCHG = false : this.RoleCHG = true;
    this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    this.data = {};
  }
 
 
  SaveAdd() {
    if (this.data.SALESMAN_CODE === null || this.data.SALESMAN_CODE === "" || this.data.SALESMAN_CODE === undefined) {
      this.modal.warning('Please insert Salesman Code', this.viewref)
    } else if (this.data.SALESMAN_NAME === null || this.data.SALESMAN_NAME === "" || this.data.SALESMAN_NAME === undefined) {
      this.modal.warning('Please insert Salesman Name', this.viewref)
    } else if (this.data.SALESMAN_ADDR1 === null || this.data.SALESMAN_ADDR1 === "" || this.data.SALESMAN_ADDR1 === undefined) {
      this.modal.warning('Please insert at least a Salesman Address', this.viewref)
    } else {
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)
    }
  }
  OpenMainDialog() {
    this.data = {};
    this.InitData();
    this.IsEdit = false;
    this.dialogMain.title = "New Salesman Code";
    this.dialogMain.OpenDialog();
  }
  ConfirmSaveAdd = () => {
    this.data.LAST_IP_ADDR = this.global.GetTokenDetail("ssIPAddress");
    this.data.ENABLE_DATE = this.getDateParam(this.data.ENABLE_DATE);   
    this.data.DISABLE_DATE = this.getDateParam(this.data.DISABLE_DATE);      
    this.http.post('AC', 'SNM029P_Save', this.data)
      .subscribe(res => {
        console.log(res)
        if (res.Table[0].STATUS == 'DONE') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
          this.SearchForAc();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }
  Edit(P_data) {
    this.data = P_data;
    this.IsEdit = true;
    this.dialogMain.title = "Edit Sales Man";
    this.dialogMain.OpenDialog();

  }

  Delete(P_data) {
    this.data.SALESMAN_CODE = P_data.SALESMAN_CODE;
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.ConfirmDeleteRow);
  }
  ConfirmDeleteRow = () => {
    this.data.LAST_IP_ADDR = this.global.GetTokenDetail("ssIPAddress");
    this.http.post('AC', 'SNM29P_Delete', this.data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.SearchForAc();
        }
      });

  }
  CancelAdd() {
    this.InitData();
    this.dialogMain.Close();
  }
 
}
