import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from '../../../core/modal.service';
import { MatTableDataSource } from '@angular/material/table';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'snm003p',
    templateUrl: './SNM003P.component.html',
    styleUrls: ['./SNM003P.component.css']
})



export class SNM003PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private modal: ModalService,
        private viewref: ViewContainerRef,
        private route: ActivatedRoute,
        private global: Globals
    ) {
    }

    @ViewChild("dialog", { static: false }) dialog: any;
    @ViewChild("dialog2", { static: false }) dialog2: any;
    public data: any = [];
    public VENDOR_CODE: any = null;
    public VENDOR_NAME: string = "";
    private RowSelect: any;
    private index: any
    public CategoryLits: any = [];
    public displayedColumns: string[] = ['category', 'description', 'on', 'off'];
    public Config: any = {
        ColName: "LOOKUP_VENDOR_NAME",
        ColValue: "",
        PlaceholderText: "Select Vendor",
        SourceController: "wPMS",
        SourceMethodName: "GetVendorCode",
        NoOfShowRecords: 100,
        MinLengthSearch: 1,
        UpperCase: true
    }

    public AddData: any = {
        CATAGORY: null,
        DESCRIPTION: null,
        STOCK_LEVEL_ON: 0,
        STOCK_LEVEL_OFF: 0,
        VENDOR_CODE: null
    }

    public EditData: any = {

        CATAGORY: null,
        DESCRIPTION: null,
        STOCK_LEVEL_ON: 0,
        STOCK_LEVEL_OFF: 0,
        VENDOR_CODE: null
    }

    public TableData: any = [];
    public hideCols: Array<string> = []

    ngOnInit() {
        this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        this.GetPartCategory();
    }

    GetPartCategory() {
        this.http.get('wPMS', 'GetPartCategory')
            .subscribe(res => {
                this.CategoryLits = res.Table;
                this.AddData.CATAGORY = this.CategoryLits[0].PART_CATEGORY
                this.AddData.DESCRIPTION = this.CategoryLits[0].CATEGORY_DESC
            })
    }

    GetData(VendoCode) {
        this.data = [];
        this.http.get('IC', 'SNM003P_GetData', VendoCode)
            .subscribe(res => {
                this.data = res.Table;

                if (res.Table.length == 0 || res.Table.length < 12) {
                    this.GenerateDefaultCategory()
                }

            })
    }


    openDialog() {

        this.dialog.OpenDialog()
    }

    CategoryChange(event, type) {

        let find = this.CategoryLits.find(x => x.PART_CATEGORY == event);

        if (type == 'ADD') {

            this.AddData.DESCRIPTION = find.CATEGORY_DESC
        } else {

            this.EditData.DESCRIPTION = find.CATEGORY_DESC
        }
    }

    CallBack(event) {
        this.VENDOR_CODE = event.VENDOR_CODE
        this.VENDOR_NAME = event.VENDOR_NAME_TH
        this.GetData(this.VENDOR_CODE);
    }

    SaveAdd() {

        this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)
    }

    keyDownFunction(event) {
        if (event.keyCode == 13) {
            this.http.get('wPMS', 'GetVendorForVendorCat', this.VENDOR_CODE)
                .subscribe(res => {
                    if (res.Table.length > 0) {
                        this.VENDOR_NAME = res.Table[0].VENDOR_NAME_TH
                        this.GetData(this.VENDOR_CODE);

                    } else {
                        this.modal.warning("Vendor Not found!", this.viewref)
                    }
                })
        }
    }

    ConfirmSaveAdd = () => {

        this.AddData.VENDOR_CODE = this.VENDOR_CODE;

        if (this.data.length > 0) {

            let found = this.data.some(x => x.CATAGORY == this.AddData.CATAGORY)

            if (found) {
                this.modal.warning('No change to save. Found duplicate record.', this.viewref)
            } else {
                this.http.post('IC', 'SNM003P_InsertVendorCategory', this.AddData)
                    .subscribe(res => {
                        if (res.Table[0].STATUS == 'Done') {
                            this.ClearData();
                            this.modal.info('Transaction complete: applied and saved.', this.viewref);
                            this.dialog.Close();
                            this.GetData(this.VENDOR_CODE);

                        } else {
                            this.modal.error('No change to save. Something went wrong.', this.viewref);
                        }
                    })
                //this.data.push(this.AddData)
                //this.data = this.data.slice();
                //this.dialog.close();
            }


        } else {
            this.http.post('IC', 'SNM003P_InsertVendorCategory', this.AddData)
                .subscribe(res => {
                    if (res.Table[0].STATUS == 'Done') {
                        this.modal.info('Transaction complete: applied and saved.', this.viewref);
                        this.dialog.Close();
                        this.GetData(this.VENDOR_CODE);
                    } else {
                        this.modal.error('No change to save. Something went wrong.', this.viewref);
                    }
                })
        }


    }

    CancelAdd() {
        //this.ClearData()
        this.dialog.Close();

    }

    ClearData() {

        this.AddData = {
            CATAGORY: this.CategoryLits[0].PART_CATEGORY,
            DESCRIPTION: this.CategoryLits[0].CATEGORY_DESC,
            STOCK_LEVEL_ON: 0,
            STOCK_LEVEL_OFF: 0,
            VENDOR_CODE: null
        }

    }

    EditCategory(data) {

        this.EditData.CATAGORY = data.CATAGORY
        this.EditData.DESCRIPTION = data.DESCRIPTION
        this.EditData.STOCK_LEVEL_ON = data.STOCK_LEVEL_ON
        this.EditData.STOCK_LEVEL_OFF = data.STOCK_LEVEL_OFF
        this.EditData.VENDOR_CODE = data.VENDOR_CODE
        this.EditData.LAST_UPD_BY = data.LAST_UPD_BY
        this.EditData.LAST_UPD_DATE = data.LAST_UPD_DATE

        this.dialog2.OpenDialog();
    }

    SaveEdit() {

        this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveEdit)

    }

    ConfirmSaveEdit = () => {

        this.http.post('IC', 'SNM003P_EditVendorCategory', this.EditData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.dialog2.Close();
                    this.GetData(this.VENDOR_CODE);
                } else {
                    this.modal.error('No change to save. Something went wrong.', this.viewref);
                }
            })
    }

    Delete() {

        this.modal.confirm('Do you want to Delete?', this.viewref, this.ConfirmDelete)
    }

    ConfirmDelete = () => {

        //this.data.splice(this.index, 1)
        //this.data = this.data.slice();
        this.http.post('IC', 'SNM003P_DeleteVendorCategory', this.EditData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.GetData(this.VENDOR_CODE);
                    this.dialog2.Close();
                } else {
                    this.modal.error('No change to save. Something went wrong.', this.viewref);
                }
            })
    }


    CancelEdit() {
        this.dialog2.Close();
    }

    GenerateDefaultCategory() {

        let item = [];
        for (let i = 1; i <= 12; i++) {

            let found = this.data.some(x => x.CATAGORY == i)
            if (!found) {
                item.push({
                    CATAGORY: i,
                    VENDOR_CODE: this.VENDOR_CODE
                })
            }
        }

        this.InsertDefaultCategory(item);

    }

    InsertDefaultCategory(item: any) {
        this.http.post('IC', 'SNM003P_InsertVendorCategory', item)
            .subscribe(res => {
                this.GetData(this.VENDOR_CODE);
            })
    }

}

