import { Component, OnInit, ViewContainerRef, ViewChild, TemplateRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import * as moment from 'moment';

@Component({
    selector: 'SNPE022_M',
    templateUrl: './SNPE022_M.component.html',
    styleUrls: ['./SNPE022_M.component.css']
})
export class SNPE022MComponent implements OnInit {
    constructor(
        protected http: HttpService,
        protected router: Router,
        protected modal: ModalService,
        protected viewref: ViewContainerRef,
        protected route: ActivatedRoute,
        protected global: Globals
    ) {
    }

    public InvoiceLookupConfig: any = {
        ColName: "INVOICE_NO",
        ColValue: "INVOICE_NO",
        PlaceholderText: "Select Invoice No.",
        SourceController: "IC",
        SourceMethodName: "SNPE022_M_GetInvoice",
        NoOfShowRecords: 50
    }

    public VendorLookupConfig: any = {
        ColName: "LOOKUP_VENDOR_NAME",
        PlaceholderText: "Select Vendor",
        SourceController: "wPMS",
        SourceMethodName: "GetVendorCode",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    public POLookupConfig: any = {
        ColName: "PO_NO",
        ColValue: "PO_NO",
        PlaceholderText: "Select PO No.",
        SourceController: "wPMS",
        SourceMethodName: "GetPONo",
        NoOfShowRecords: 50,
        UpperCase: true
    }

    public InvoiceNo: string;
    public InvoiceDate: moment.Moment;
    public ShippedDate: moment.Moment;
    public Vendor: string;
    public VendorCode: string;
    public VendorName: string;
    public PONo: string;
    public DialogDataList: Array<any> = [];
    public SelectedPOList: Array<any> = [];
    public isLocked: boolean = false;

    @ViewChild('dialog', { static: false }) dialog: any;

    ngOnInit(): void {
        this.CreateDetailRow(0);
    }

    ShowInvoiceDetail(showMessage: boolean = true) {
        this.isLocked = false;
        this.http.get("IC", "SNPE022_M_Query", this.InvoiceNo || "null", this.VendorCode || "null")
            .subscribe(result => {
                if (result.Table.length > 0) {
                    this.SelectedPOList = result.Table;
                    this.isLocked = true;
                    this.InvoiceDate = result.Table[0].INVOICE_DATE;
                    this.ShippedDate = result.Table[0].SHIPPED_DATE;
                    if (showMessage) {
                        this.modal.info("Duplicate invoice found!", this.viewref)
                    }
                }
            })
    }

    NewInvoice() {
        if (this.isLocked) {
            this.InvoiceNo = null;
            this.InvoiceDate = null;
            this.ShippedDate = null;
            this.Vendor = null;
            this.VendorCode = null;
            this.VendorName = null;
            this.PONo = null;
            this.DialogDataList = [];
            this.SelectedPOList = [];
            this.isLocked = false;
            this.CreateDetailRow(0);
        } else {
            this.modal.confirm("Are you sure to new invoice?<br>All changes will be cleared.", this.viewref
                , () => {
                    this.InvoiceNo = null;
                    this.InvoiceDate = null;
                    this.ShippedDate = null;
                    this.Vendor = null;
                    this.VendorCode = null;
                    this.VendorName = null;
                    this.PONo = null;
                    this.DialogDataList = [];
                    this.SelectedPOList = [];
                    this.isLocked = false;
                    this.CreateDetailRow(0);
                }, () => { })
        }
    }

    public CheckChangeData() {
        return this.VendorCode || this.InvoiceNo || this.InvoiceDate || this.ShippedDate || this.SelectedPOList.find(v => v._editRow);
    }

    public CheckSaveData() {
        return this.VendorCode && this.InvoiceNo && this.InvoiceDate && this.ShippedDate && this.SelectedPOList.find(v => v._editRow);
    }

    SaveSelectedDetail() {
        let saveableList = this.SelectedPOList.filter(v => v._editRow)
        saveableList.forEach(x => {
            x.INVOICE_NO = this.InvoiceNo;
            x.INVOICE_DATE = this.InvoiceDate;
            x.SHIPPED_DATE = this.ShippedDate;
            x.VENDOR_CODE = this.VendorCode;
            // x.PO_NO = this.PONo;
            x._ETP_DATE = x.ETP_DATE;
        });

        if (saveableList.length > 0) {
            this.modal.confirm("Are you sure to save these changes?", this.viewref
                , () => {
                    this.http.post("IC", "SNPE022_M_SaveInvoice", saveableList)
                        .subscribe(result => {
                            this.modal.info("Saved successfully.", this.viewref);
                            this.ShowInvoiceDetail(false);
                        }, err => {
                            this.modal.error(err.message, this.viewref);
                        })
                })
        } else {
            this.modal.error("No row to be process.", this.viewref);
        }
    }

    SetVendorLookup(vendor: any) {
        this.VendorCode = vendor.VENDOR_CODE;
        this.VendorName = vendor.VENDOR_NAME_EN;
        this.Vendor = vendor.LOOKUP_VENDOR_NAME;
        this.ShowInvoiceDetail();
    }

    SetInvoiceLookup(invoice: any) {
        if (invoice) {
            this.InvoiceNo = invoice;
            this.ShowInvoiceDetail();
        }
    }

    SetPOLookup(poNo: any) {

        this.http.get("IC", "SNPE022_M_QueryNullInv", this.VendorCode, poNo)
            .subscribe(result => {
                this.DialogDataList = result.Table.filter(v => !this.SelectedPOList.find(d => v.PO_NO === d.PO_NO && v.ITEM_NO === d.ITEM_NO && v.SUB_ITEM_NO === d.SUB_ITEM_NO));

                this.dialog.OpenDialog();
            })
    }

    CreateDetailRow(tblIndex) {
        let currentMaxRow: number = this.SelectedPOList.length || 0;
        let nextMaxRow: number = (Math.floor(currentMaxRow / 10) + 1) * 10;

        if (currentMaxRow - tblIndex <= 2) {
            for (let i = currentMaxRow; i < nextMaxRow; i++) {
                this.SelectedPOList.push({});
            }

            this.SelectedPOList = this.SelectedPOList.slice();
        }

    }

    UpdateInvoiceDetail() {
        let ActiveRow = this.SelectedPOList.filter(v => v._editRow);
        let SelectedDetail = this.DialogDataList.filter(v => v._editRow);
        this.SelectedPOList = Array.prototype.concat(ActiveRow, SelectedDetail)

        this.CreateDetailRow(this.SelectedPOList.length - 1);
        this.dialog.Close();
    }

    DeSelectRow(index: number) {
        this.modal.confirm("Are you sure to remove this row?", this.viewref
            , () => {
                this.SelectedPOList.splice(index, 1);
                this.SelectedPOList = this.SelectedPOList.slice();
            }, () => { })
    }

}
