import { Component, OnInit, ViewContainerRef, Input, Output, OnChanges, EventEmitter } from '@angular/core';
import { SNPE022MComponent } from '../../SNPE022_M.component';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'part-list',
    templateUrl: './part-list.component.html',
    styleUrls: ['./../../SNPE022_M.component.css']
})
export class SNPE022MPartListComponent extends SNPE022MComponent implements OnInit, OnChanges {

    constructor(
        protected http: HttpService,
        protected router: Router,
        protected modal: ModalService,
        protected viewref: ViewContainerRef,
        protected route: ActivatedRoute,
        protected global: Globals
    ) {
        super(http, router, modal, viewref, route, global);
    }

    @Input() public DataList: Array<any> = [];
    @Input() public vendorCode: string;
    @Output() public DataListChange = new EventEmitter<Array<any>>();

    public SelectedPartName: string;
    public SelectedUpdateBy: string;
    public SelectedUpdateDate: Date;

    public PartNoLookupConfig: any = {
        ColName: "LOOKUP_PART_NAME",
        PlaceholderText: "Select Part No.",
        SourceController: "wPMS",
        SourceMethodName: "GetPartNo",
        NoOfShowRecords: 20
    }

    ngOnInit(): void { 
        this.PartNoLookupConfig.SourceParams.VENDOR_CODE = this.vendorCode;
    }

    ngOnChanges() {
        this.SelectedPartName = null;
        this.SelectedUpdateBy = null;
        this.SelectedUpdateDate = null;

        this.PartNoLookupConfig.SourceParams.VENDOR_CODE = this.vendorCode;
    }

    SetNewPartNo(part: any, data: any) {
        data.ACCEPT_PART_NO = part.PART_NO;
        data.PART_NAME_EN = part.PART_NAME;

        this.SetPartName(data);
    }

    SetPartName(data: any) {
        this.SelectedPartName = data.PART_NAME_EN;
        this.SelectedUpdateBy = data.LAST_UPD_BY;
        this.SelectedUpdateDate = data.LAST_UPD_DATE;
    }

    CheckBoxChecked(evt: any, data: any) {
        if (evt) {
            data._STATUS_CODE = data.STATUS_CODE;
            data._ACCEPT_PART_NO = data.ACCEPT_PART_NO;
            data._ACCEPT_QTY = data.ACCEPT_QTY;
            data._ETP_DATE = data.ETP_DATE;

            data.STATUS_CODE = "50";
        } else {
            this.modal.confirm("Are you sure to unselect? All changes in this row will be reverted.", this.viewref
                , () => {
                    data.STATUS_CODE = data._STATUS_CODE;
                    data.ACCEPT_PART_NO = data._ACCEPT_PART_NO;
                    data.ACCEPT_QTY = data._ACCEPT_QTY;
                    data.ETP_DATE = data._ETP_DATE;
                }, () => {
                    data._editRow = true;
                })
        }
    }

    ValidateMaxQTY(data: any) {
        data.ACCEPT_QTY = data.ACCEPT_QTY > data.MAX_ACCEPT_QTY ? data.MAX_ACCEPT_QTY : data.ACCEPT_QTY;
    }
}
