import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from '../../../core/global';

@Component({
  selector: 'snpr008_m',
  templateUrl: './SNPR008_M.component.html',
  styleUrls: ['./SNPR008_M.component.css']
})

export class SNPR008_MComponent implements OnInit {

  public Vendor_Type_List: any = [];

  public strStaffName;

  constructor(
    private HttpService: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {
  }

  public lookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    ColValue: "VENDOR_CODE",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }



  public lookupConfigGroupPart: any = {
    ColName: "LOOKUP_PART_NAME",
    ColValue: "GROUP_PART_NO",
    PlaceholderText: "Select Group Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetGroupPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 5,
    UpperCase: true
  }

  public lookupConfigVendorStaff: any = {
    ColName: "LOOKUP_STAFF_NAME",
    PlaceholderText: "Select Vendor Staff",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorStaff",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  //autoc v kool

  public ListDataReportCondition: any = {

    VENDOR_CODE_FROM: null,
    VENDOR_CODE_TO: null,
    VENDOR_TYPE_FROM: null,
    VENDOR_TYPE_TO: null,
    PART_NO_FROM: null,
    PART_NO_TO: null,
    STAFF_ID: null,

  };

  ngOnInit() {
    this.Vendor_Type_List = [{ ID: '', TEXT: "" }, { ID: 'J', TEXT: "J:Japan" }, { ID: 'K', TEXT: "K:Import(Not Japan)" }, { ID: 'L', TEXT: "L:Local" }]
  }

  Search() {
    if (this.CheckSearchCondition()) {
      this.GoToReport();//show roport viewer.
    }
  }

  SearchRAW() {
    if (this.CheckSearchCondition()) {
      this.GoToReportRAW();//show roport viewer.
    }
  }

  GoToReport() {
    this.global.GoToReport("PMS_RPT_IC_SNPR008_M", {
      P_PART_NO_FROM: this.ListDataReportCondition.PART_NO_FROM,
      P_PART_NO_TO: this.ListDataReportCondition.PART_NO_TO,
      P_VENDOR_CODE_FROM: this.ListDataReportCondition.VENDOR_CODE_FROM,
      P_VENDOR_CODE_TO: this.ListDataReportCondition.VENDOR_CODE_TO,
      P_VENDOR_TYPE_FROM: this.ListDataReportCondition.VENDOR_TYPE_FROM,
      P_VENDOR_TYPE_TO: this.ListDataReportCondition.VENDOR_TYPE_TO,
      P_STAFF_ID: this.ListDataReportCondition.STAFF_ID
    })
  }
  GoToReportRAW() {
    this.global.GoToExport("PMS_RPT_IC_SNPR008_M_Raw", {
      P_PART_NO_FROM: this.ListDataReportCondition.PART_NO_FROM,
      P_PART_NO_TO: this.ListDataReportCondition.PART_NO_TO,
      P_VENDOR_CODE_FROM: this.ListDataReportCondition.VENDOR_CODE_FROM,
      P_VENDOR_CODE_TO: this.ListDataReportCondition.VENDOR_CODE_TO,
      P_VENDOR_TYPE_FROM: this.ListDataReportCondition.VENDOR_TYPE_FROM,
      P_VENDOR_TYPE_TO: this.ListDataReportCondition.VENDOR_TYPE_TO,
      P_STAFF_ID: this.ListDataReportCondition.STAFF_ID
    }, true, 'EXCELOPENXML')
  }

  CheckSearchCondition() {
    let boolHadSelectedCondition: boolean;
    boolHadSelectedCondition = false;//maening: User is not selecting condition search report.
    //define Emply string to Null, when call report, emply string will not sent to server report.
    if (!this.ListDataReportCondition.VENDOR_CODE_FROM) { this.ListDataReportCondition.VENDOR_CODE_FROM = null; }
    if (!this.ListDataReportCondition.VENDOR_CODE_TO) { this.ListDataReportCondition.VENDOR_CODE_TO = null; }

    if (!this.ListDataReportCondition.VENDOR_TYPE_FROM) { this.ListDataReportCondition.VENDOR_TYPE_FROM = null; }
    if (!this.ListDataReportCondition.VENDOR_TYPE_TO) { this.ListDataReportCondition.VENDOR_TYPE_TO = null; }

    if (!this.ListDataReportCondition.PART_NO_FROM) { this.ListDataReportCondition.PART_NO_FROM = null; }
    if (!this.ListDataReportCondition.PART_NO_TO) { this.ListDataReportCondition.PART_NO_TO = null; }

    if (!this.ListDataReportCondition.STAFF_ID) { this.ListDataReportCondition.STAFF_ID = null; }
    //console.log("When clear emply string:",this.ListDataReportCondition);

    //check From and To condition when user select only from or only to. must put value to it.
    if (this.ListDataReportCondition.VENDOR_CODE_FROM == null) { this.ListDataReportCondition.VENDOR_CODE_FROM = this.ListDataReportCondition.VENDOR_CODE_TO; boolHadSelectedCondition = true; }
    if (this.ListDataReportCondition.VENDOR_CODE_TO == null) { this.ListDataReportCondition.VENDOR_CODE_TO = this.ListDataReportCondition.VENDOR_CODE_FROM; boolHadSelectedCondition = true; }

    if (this.ListDataReportCondition.VENDOR_TYPE_FROM == null) { this.ListDataReportCondition.VENDOR_TYPE_FROM = this.ListDataReportCondition.VENDOR_TYPE_TO; boolHadSelectedCondition = true; }
    if (this.ListDataReportCondition.VENDOR_TYPE_TO == null) { this.ListDataReportCondition.VENDOR_TYPE_TO = this.ListDataReportCondition.VENDOR_TYPE_FROM; boolHadSelectedCondition = true; }

    if (this.ListDataReportCondition.PART_NO_FROM == null) { this.ListDataReportCondition.PART_NO_FROM = this.ListDataReportCondition.PART_NO_TO; boolHadSelectedCondition = true; }
    if (this.ListDataReportCondition.PART_NO_TO == null) { this.ListDataReportCondition.PART_NO_TO = this.ListDataReportCondition.PART_NO_FROM; boolHadSelectedCondition = true; }

    return boolHadSelectedCondition;
  }


}