import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { FormControl } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { MatDatepicker } from '@angular/material/datepicker';
import { Globals } from 'src/app/core/global';
import * as moment from 'moment';


@Component({
  selector: 'snsd141_99_1',
  templateUrl: './snsd141_99_1.component.html',
  styleUrls: ['./snsd141_99_1.component.css']
})


export class SNSD141_99_1Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    private global: Globals
  ) {
  }

  private origin: string = window.location.protocol + "//" + window.location.hostname + ":8090";
  public StaffCode: any;
  public VendorCode: any;
  public Staff_Text: any = [];
  public TName: any = [];
  public formData: any = { AGED_BO: 0, StaffCode: null, VendorCode: null, };
  public date = new FormControl(new Date());

  public lookupConfig: any = {
    ColName: "STAFF_NAME",
    PlaceholderText: "Select Staff Incharge",
    SourceController: "IC",
    SourceMethodName: "SNSD141_99_1_FindStaff",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      VENDOR_CODE: this.formData.VendorCode
    }
  }

  public lookupConfigVendor: any = {
    ColName: "VENDOR",
    ColValue: "VENDOR_CODE",
    PlaceholderText: "Select Vendor",
    SourceController: "IC",
    SourceMethodName: "SNSD141_99_1_FindVendor",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      SK_USER_ID: this.formData.StaffCode
    }
  }

  ngOnInit() {
    this.formData.ETD_DATE_FROM = moment()
    this.formData.ETD_DATE_TO = moment()
    this.formData.AGED_BO = 0;
  }


  SetStaffCodeLookup(s) {
    this.formData.StaffCode = s.SK_USER_ID;
    this.Staff_Text = {
      ENAME: s.ENAME,
      TNAME: s.TNAME
    };
    this.lookupConfigVendor.SourceParams.SK_USER_ID = s.SK_USER_ID;
    // this.Staff_Change(s);
  }

  SetVendorCodeLookup(v) {
    this.formData.VendorCode = v;
    this.lookupConfig.SourceParams.VENDOR_CODE = v;
    //this.Staff_Change(even);
  }



  ExportDataBO() {
    this.global.GoToExport(
      "PMS_RPT_IC_SNSD141_99_1",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_VENDOR_CODE: this.formData.VendorCode,
        P_AGED_BO: this.formData.AGED_BO,
        P_ETD_DATE_FROM: this.global.ConvertDateToFormatSTD(this.formData.ETD_DATE_FROM),
        P_ETD_DATE_TO: this.global.ConvertDateToFormatSTD(this.formData.ETD_DATE_TO),
        P_STAFF_INCHARGE: this.formData.StaffCode
      }, true, "EXCELOPENXML"
    )

    // this.formData.ETD_DATE_FROM = this.SetFormateDate(this.formData.ETD_DATE_FROM);
    // this.formData.ETD_DATE_TO = this.SetFormateDate(this.formData.ETD_DATE_TO);
    // this.formData.ENAME = this.Staff_Text.ENAME;
    // this.http.Download("IC", "SNSD141_99_1_GetDataBO", JSON.stringify(this.formData))
    //     .subscribe(result => {
    //         if (result) {

    //             this.download(result)
    //             //this.modal.info("Saved data successfully", this.viewref);
    //         }
    //     }, (err) => {
    //         console.log(err, 'err')
    //     })

  }

  ViewReportBO() {
    this.global.GoToReport(
      "PMS_RPT_IC_SNSD141_99_1",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_VENDOR_CODE: this.formData.VendorCode,
        P_AGED_BO: this.formData.AGED_BO,
        P_ETD_DATE_FROM: this.global.ConvertDateToFormatSTD(this.formData.ETD_DATE_FROM),
        P_ETD_DATE_TO: this.global.ConvertDateToFormatSTD(this.formData.ETD_DATE_TO),
        P_STAFF_INCHARGE: this.formData.StaffCode
      }
    )
  }

  SetFormateDate(date) {

    let d = new Date(date);
    let day = d.getDate();
    let newDay = day.toString().length < 2 ? 0 + '' + day.toString() : day.toString()
    let m = d.getMonth() + 1;
    let newMonth = m.toString().length < 2 ? 0 + '' + m.toString() : m.toString()
    let y = d.getFullYear();
    return newDay + '/' + newMonth + '/' + y;
  }


  download(content) {

    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type })
    a.href = URL.createObjectURL(file);
    a.download = "SNSD141_99_1.csv"
    a.click()
  }

  OpendateFromPopup(datepicker: MatDatepicker<any>) {

    datepicker.open();
  }

  OpendateToPopup(datepicker: MatDatepicker<any>) {

    datepicker.open();
  }

}

