import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snsd148_f',
  templateUrl: './snsd148_f.component.html',
  styleUrls: ['./snsd148_f.component.css']
})



export class SNSD148_FComponent implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    private route: ActivatedRoute,
    private global: Globals
  ) {
  }

  public OverseaFlag: string = "A";
  public Vendor: string;
  public VendorCode: string;
  public StaffId: string;
  public StaffNameENG: string = "";
  public StaffNameTH: string = "";
  public isStaffSelected: boolean = false;

  public lookupStaffConfig: any = {
    ColName: "LOOKUP_STAFF_NAME",
    PlaceholderText: "Select Staff Incharge",
    SourceController: "IC",
    SourceMethodName: "SNSD148_F_GetStaff",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      VendorCode: null
    }
  }

  public lookupVendorConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "IC",
    SourceMethodName: "SNSD148_F_GetVendor",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      StaffID: null,
      OverseaFlag: null
    }
  }

  ngOnInit() {

  }

  SetStaffLookup(val) {
    this.StaffId = val.STAFF_ID;
    this.StaffNameENG = val.ENAME || '';
    this.StaffNameTH = val.TNAME || '';

    this.isStaffSelected = this.StaffId ? true : false;

    this.lookupVendorConfig.SourceParams.StaffID = this.StaffId || null;
  }

  SetVendorLookup(val) {
    this.Vendor = val.LOOKUP_VENDOR_NAME;
    this.VendorCode = val.VENDOR_CODE || null;
    this.lookupStaffConfig.SourceParams.VendorCode = this.VendorCode || null;
  }

  ChangeOverseaFlag(event) {
    this.lookupVendorConfig.SourceParams.OverseaFlag = event.value;
  }

  ExportToExcel() {
    this.global.GoToExport("PMS_RPT_IC_SNSD148_F", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_OVERSEA_FLAG: this.OverseaFlag,
      P_STAFF_ID: this.StaffId,
      P_VENDOR_CODE: this.VendorCode,
    }, true, "EXCELOPENXML")
  }
  

  ExportToExcel2() {
    this.global.GoToExport("PMS_RPT_IC_SNSD148_F_2", {
      P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
      P_OVERSEA_FLAG: this.OverseaFlag,
      P_STAFF_ID: this.StaffId,
      P_VENDOR_CODE: this.VendorCode,
    }, true, "EXCELOPENXML")
  }

}


