import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from '../../../core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';

@Component({
  selector: 'snse155',
  templateUrl: './snse155.component.html',
  styleUrls: ['./snse155.component.css']
})



export class SNSE155Component implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private router: Router,
    private route: ActivatedRoute,
    private global: Globals,
    private viewref: ViewContainerRef
  ) { 

  }

  public tabledata: any = [];
  public PROCESS_LOG: any = [];
  public MainModelPMSDetail: any;


  @ViewChild("dialogEditMainModelPMS") dialogEditMainModelPMS: any

  public params = {
    CATALOG_MODEL: null,
    MAIN_MODEL_PMS: null,
    MAIN_MODEL_NAME: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    UPDATE_BY: null,
    UPDATE_DATE: null
  }

  ngOnInit() {

  }

  public Search() {
    this.tabledata = [];
    this.http.post("IC", "SNSE155_getSearch", this.params)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }

  public ExportExcel() {
    this.http.Download("IC", "SNSE155_Export_Excel", JSON.stringify(this.tabledata))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
          this.PROCESS_LOG.push('Export complete ' + this.tabledata.length + ' records.');
        } else {
          this.modal.error('Download not complete', this.viewref)
        }
      })
  }

  public WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    var date_export = new Date();
    a.href = URL.createObjectURL(file);
    a.download = "SNSE155" + "_" + date_export.getFullYear() + "/" + (date_export.getMonth() + 1) + "/" + date_export.getDate() + ".csv";
    a.click();
  }


  public editRow(row: any, index: any) {
    this.MainModelPMSDetail = cloneDeep(row);
    this.dialogEditMainModelPMS.OpenDialog();
  }

  public UpdateMainModelMapping() {
    this.modal.confirm("Do you want to save your change?", this.viewref,
      () => {
        this.http.post('IC', 'SNSE155_Update', this.MainModelPMSDetail)
          .subscribe(res => {
            if (res.Table[0].STATUS === "Done") {
              this.modal.info('Save successfully', this.viewref)
              this.Search();
              this.dialogEditMainModelPMS.Close();
            }
          }, (err) => {
            console.log(err, 'err')
          })
      }, () => { })
  }


  public ConfigCatalogModel: any = {
    ColName: "CATALOG_MODEL_PFPM",
    PlaceholderText: "Select Catalog Model",
    SourceController: "IC",
    SourceMethodName: "SNSE155_getCatalogModel",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public ConfigMainModelPMS: any = {
    ColName: "LOOKUP_MAIN_MODEL_PMS",
    PlaceholderText: "Select Main Model PMS",
    SourceController: "IC",
    SourceMethodName: "SNSE155_getMainModelPMS",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }


  public SetCatalogModel(values: any) {
    this.params.CATALOG_MODEL = values.CATALOG_MODEL_PFPM;
  }

  public SetMainModelPMS(values: any) {
    this.MainModelPMSDetail.MAIN_MODEL_PMS = values.MAIN_MODEL_PMS;
  }

}
