import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snpe003',
  templateUrl: './snpe003.component.html',
  styleUrls: ['./snpe003.component.css']
})


export class SNPE003Component implements OnInit {

  constructor(
    private httpService: HttpService,
    private router: Router,
    public modal: ModalService,
    public viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute

  ) {

  }

  //public searchCriteria = { VendorCode: '',VendorName:"", VendorType: '' };
  public vendorInfoResult: any;
  public searchResult: Array<any> = [];
  public dataList: Array<any> = [];
  public headerList: any;
  public displayedColumns: string[] = [];
  public formName: any;
  public Vendor = "";
  public VendorCode = "";
  public VendorType = "";

  public dataGPart: any = {};
  public dataDom: any = {};
  public dataExport: any = {};
  public dataIndent: any = {};
  public dataDemand: any = {};
  public partNo: string = '';

  private viewRow: any;

  public VendorLookupConfig: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 50,
    UpperCase: true
  }


  ngOnInit() {
  }

  getVendorInfo() {
    this.VendorType = "";
    if (this.VendorCode != "") {
      this.httpService.get("IC", "SNPE003_GetVendorInfo", this.VendorCode)
        .subscribe(result => {

          if (result.Table.length > 0) {

            this.VendorType = result.Table[0].VENDOR_TYPE_DESC;

          }
          else {
            this.VendorType = "";
            //this.modal.error("There is no vendor information!", this.viewref);
          }
        })
    }
  }

  // SetVendorCodeLookup(event) {
  //     this.searchCriteria.VendorCode = event.VENDOR_CODE;
  //     //this.getVendorInfo();
  // }

  ValidateSearchVendor(autoComplete) {
    autoComplete.query()

    if (!this.Vendor) {
      this.VendorCode = "";
      this.dataGPart = {};
      this.dataDom = {};
      this.dataExport = {};
      this.dataIndent = {};
      this.dataDemand = {};
      this.partNo = '';
      this.getVendorInfo();
      this.getPoSuggestion();


    }
  }


  SetVendorCodeLookup(value) {
    this.Vendor = value.LOOKUP_VENDOR_NAME;
    this.VendorCode = value.VENDOR_CODE;
    this.getVendorInfo();
    this.getPoSuggestion();
    this.partNo = '';
  }

  getPoSuggestion() {
    this.dataList = [];

    this.dataGPart = {};
    this.dataDom = {};
    this.dataExport = {};
    this.dataIndent = {};
    this.dataDemand = {};
    this.partNo = '';

    this.httpService.get("IC", "SNPE003_GetPoSuggestion", this.VendorCode)
      .subscribe(result => {
        this.dataList = result.Table;

        this.dataList.forEach((e) => {
          if (typeof e === "object") {
            e["_CancelRequest"] = "",
              e["_ValidOrderQtyBef"] = e.SUGGEST_ORDER_QTY,
              e["_RecheckOrderQty"] = e.SUGGEST_ORDER_QTY,
              e["_RecheckLockSuggest"] = e.LOCK_SUGGEST
          }
        });


      })
  }

  //Calculate suggestion amount when confirming suggustion qty
  calculateAmount(row) {
    row.SUGGEST_ORDER_AMOUNT = row.SUGGEST_ORDER_QTY * row.SUGGEST_BASE_PRICE;

  }

  onBlurOrderQty(row) {
    let isPoValid: boolean = row.SUGGEST_ORDER_QTY % row.PO_PACKAGE == 0 ? true : false;

    if (!isPoValid && row.SUGGEST_ORDER_QTY != row._RecheckOrderQty) {
      this.modal.error('Order quantity is invalid due to PO package is ' +
        row.PO_PACKAGE +
        '. The quantity will be reset to ' + row._ValidOrderQtyBef, this.viewref);

      row.SUGGEST_ORDER_QTY = row._ValidOrderQtyBef;
      row.SUGGEST_ORDER_AMOUNT = row.SUGGEST_ORDER_QTY * row.SUGGEST_BASE_PRICE;
    } else {
      row._ValidOrderQtyBef = row.SUGGEST_ORDER_QTY;
    }

  }

  onRequestCancelChange(e, row) {
    row._CancelRequest = e.checked ? 'Y' : '';
  }

  onClickRow(row) {
    this.viewRow = row;
    this.dataGPart.OH_QTY = 0;
    this.dataGPart.PO_QTY = 0;
    this.dataGPart.BO_QTY = 0;

    this.partNo = row.GROUP_PART_NO;
    this.httpService.get("IC", "SNPE003_GetPartInfo", row.GROUP_PART_NO)
      .subscribe(result => {
        this.dataGPart = result.Table[0];

        if (result.Table1[0] == undefined) {
          this.dataDom.ORDER_QTY_N_01 = 0;
          this.dataDom.ORDER_QTY_N_02 = 0;
          this.dataDom.ORDER_QTY_N_03 = 0;
          this.dataDom.ORDER_QTY_N_04 = 0;
          this.dataDom.ORDER_QTY_N_05 = 0;
          this.dataDom.ORDER_QTY_N_06 = 0;
          this.dataDom.ORDER_QTY_N_07 = 0;
          this.dataDom.ORDER_QTY_N_08 = 0;
          this.dataDom.ORDER_QTY_N_09 = 0;
          this.dataDom.ORDER_QTY_N_10 = 0;
          this.dataDom.ORDER_QTY_N_11 = 0;
          this.dataDom.ORDER_QTY_N_12 = 0;
        } else {
          this.dataDom = result.Table1[0];
        }

        if (result.Table2[0] == undefined) {
          this.dataExport.ORDER_QTY_N_01 = 0;
          this.dataExport.ORDER_QTY_N_02 = 0;
          this.dataExport.ORDER_QTY_N_03 = 0;
          this.dataExport.ORDER_QTY_N_04 = 0;
          this.dataExport.ORDER_QTY_N_05 = 0;
          this.dataExport.ORDER_QTY_N_06 = 0;
          this.dataExport.ORDER_QTY_N_07 = 0;
          this.dataExport.ORDER_QTY_N_08 = 0;
          this.dataExport.ORDER_QTY_N_09 = 0;
          this.dataExport.ORDER_QTY_N_10 = 0;
          this.dataExport.ORDER_QTY_N_11 = 0;
          this.dataExport.ORDER_QTY_N_12 = 0;
        } else {
          this.dataExport = result.Table2[0];
        }

        if (result.Table3[0] == undefined) {
          this.dataIndent.ORDER_QTY_N_01 = 0;
          this.dataIndent.ORDER_QTY_N_02 = 0;
          this.dataIndent.ORDER_QTY_N_03 = 0;
          this.dataIndent.ORDER_QTY_N_04 = 0;
          this.dataIndent.ORDER_QTY_N_05 = 0;
          this.dataIndent.ORDER_QTY_N_06 = 0;
          this.dataIndent.ORDER_QTY_N_07 = 0;
          this.dataIndent.ORDER_QTY_N_08 = 0;
          this.dataIndent.ORDER_QTY_N_09 = 0;
          this.dataIndent.ORDER_QTY_N_10 = 0;
          this.dataIndent.ORDER_QTY_N_11 = 0;
          this.dataIndent.ORDER_QTY_N_12 = 0;
        } else {
          this.dataIndent = result.Table3[0];
        }

        this.dataDemand = result.Table4[0];
      })

  }

  NumericKeyDown(event) {
    //console.log('Keydonw',event);
    let reg = /^[0-9]$/;

    if (event.keyCode == 8 || event.keyCode == 9 || event.keyCode == 46
      || event.keyCode == 37 || event.keyCode == 39) {
      return true;
    }

    return reg.test(event.key);
  }

  QuantityKeyDown(row, event) {
    //console.log('QuantityKeyDown',row);
    let reg = /^[0-9]$/;

    if (event.keyCode == 8 || event.keyCode == 9 || event.keyCode == 46
      || event.keyCode == 37 || event.keyCode == 39 || event.keyCode == 189) {

      if (!row.SUGGEST_ORDER_QTY) {
        row.SUGGEST_ORDER_QTY = 0;
      }

      return true;
    }

    return reg.test(event.key);
  }
  saveChage = () => {
    console.log('Confirm Yes!!!');

    var i;
    let dirtyList: any = [];
    //console.log(this.dataList);

    for (i = 0; i < this.dataList.length; i++) {

      if (this.dataList[i]._CancelRequest == 'Y' ||
        this.dataList[i]._RecheckOrderQty != this.dataList[i].SUGGEST_ORDER_QTY ||
        this.dataList[i]._RecheckLockSuggest != this.dataList[i].LOCK_SUGGEST
      ) {
        dirtyList.push(this.dataList[i]);
      }
    }

    //console.log('Dirty List ', dirtyList);

    if (dirtyList.length > 0) {
      this.httpService.post('IC', 'SNPE003_SaveChange', JSON.stringify(dirtyList))
        .subscribe(res => {
          if (res === "Done") {
            this.modal.info('Success', this.viewref)
            this.getPoSuggestion();
            //this.openDialog('Message from the system', 'Success')
          } else {
            this.modal.error('Failed', this.viewref)
          }

        });
    }
    else {
      this.modal.info("There is no dirty record to save!", this.viewref);
    }

  }

  closeExpand(row) {
    if (JSON.stringify(this.viewRow) !== JSON.stringify(row)) {
      this.dataGPart = {};
      this.dataDom = {};
      this.dataExport = {};
      this.dataIndent = {};
      this.partNo = '';
    }
  }

}


