import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewContainerRef, ViewChild } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snpe007',
  templateUrl: './snpe007.component.html',
  styleUrls: ['./snpe007.component.css']
})



export class SNPE007Component implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewRef: ViewContainerRef,
    private global: Globals,
    private router: Router
  ) { }


  public INVOICE_NO: string = '';
  public INVOICE_DATE: string = '';
  public VENDOR_CODE: string = '';
  public mtCurrencyCode: any = [];
  public dataHeader: any = [];
  public dataDetail: any = {};
  public dataSummary: any = [];
  public dataPartList: any = {};
  public calDetail: any = {};

  public VendorConfig: any = {
    ColName: "VENDOR_TEXT",
    ColValue: "",
    PlaceholderText: "Select Vendor Code",
    SourceController: "IC",
    SourceMethodName: "SNPR019_FindFVendor",
    NoOfShowRecords: 50,
    MinLengthSearch: 2,
    UpperCase: true
  }

  public InvoiceConfig: any = {
    ColName: "INVOICE_VENDOR",
    ColValue: "",
    PlaceholderText: "Select Invoice No.",
    SourceController: "wPMS",
    SourceMethodName: "GetInvoiceImport",
    NoOfShowRecords: 50,
    MinLengthSearch: 3,
    UpperCase: true
  }


  public tblFooter: any = [
    {
      fieldName: "ACCEPT_PART_NO",
      value: "Total",
      show: true
    },
    {
      fieldName: "CIF_FREIGHT_AMT_B",
      show: true
    },
    {
      fieldName: "CIF_INSURANCE_AMT_B",
      show: true
    },
    {
      fieldName: "CIF_OTHER_AMT_B",
      show: true
    },
    {
      fieldName: "EXP_CLEANRANCE_AMT_B",
      show: true
    },
    {
      fieldName: "EXP_FREIGHT_AMT_B",
      show: true
    },
    {
      fieldName: "EXP_OTHER_AMT_B",
      show: true
    },
    {
      fieldName: "INCOME_TAX",
      show: true
    },
    {
      fieldName: "EXCISE_TAX",
      show: true
    },
    {
      fieldName: "INTERIOR_TAX",
      show: true
    },
    {
      fieldName: "RACK_DUTY",
      show: true
    },
    {
      fieldName: "OTHER_TAX",
      show: true
    },
    {
      fieldName: "TOT_AMT_B",
      show: true
    },
    {
      fieldName: "TOT_AMT_C",
      show: true
    },
    {
      fieldName: "FREIGHT_AMT_B",
      show: true
    },
    {
      fieldName: "INS_AMT_B",
      show: true
    },
    {
      fieldName: "EXPENSE_AMT_B",
      show: true
    },
    {
      fieldName: "DUTY_AMT_B",
      show: true
    },
    {
      fieldName: "OTHER_AMT_B",
      show: true
    },
    {
      fieldName: "TOT_AMT_CIF_B",
      show: true
    },
    {
      fieldName: "TOT_QTY",
      show: true
    },
    {
      fieldName: "TOT_GOODS",
      show: true
    },
    {
      fieldName: "TOT_GOODS_CUSTOM",
      show: true
    },
    {
      fieldName: "TOT_AMT_ALL",
      show: true
    }


  ]

  public IsCalculate : boolean = false;

  ngOnInit() {
    this.dataHeader.C_AUTO_CAL_DUTY = true;
  }

  public InvoiceChanged(value: any) {
   
    this.INVOICE_NO = value.INVOICE_NO;
    this.INVOICE_DATE = value.INVOICE_DATE;
    this.VENDOR_CODE = value.VENDOR_CODE;
    this.GetInvData(0);
  }

  private GetInvData(p_Cal) {
    var tmp = '';
    tmp = this.dataHeader.C_AUTO_CAL_DUTY;

    this.http.get("AC", "SNPE007_GetInvoiceInfo", this.INVOICE_NO, this.INVOICE_DATE, this.VENDOR_CODE)
      .subscribe(result => {
      
        this.dataHeader = result.Table[0];
        // console.log(this.dataHeader,'hhhhhhhh')
        this.dataDetail = result.Table1;
        if (p_Cal != 1) {
          this.dataSummary = result.Table2[0];
        }
        this.dataHeader.C_AUTO_CAL_DUTY = tmp;
      })
  }

  private SetAmount() {

    //--- OTHER_AMT_C separate to (new) CIF_FREIGHT_AMT_C + CIF_INSURANCE_AMT_C + CIF_OTHER_AMT_C
    this.dataHeader.OTHER_AMT_B = this.global.Round((this.dataHeader.CIF_FREIGHT_AMT_C + this.dataHeader.CIF_INSURANCE_AMT_C + this.dataHeader.CIF_OTHER_AMT_C)
      * (this.dataHeader.EXCHANGE_RATE / this.dataHeader.DP_EXCHANGE_UNIT),2);

    //--- EXPENSE_AMT_B [Total (3)] separate to
    this.dataHeader.EXPENSE_AMT_B = this.dataHeader.EXP_CLEANRANCE_AMT_B + this.dataHeader.EXP_FREIGHT_AMT_B + this.dataHeader.EXP_OTHER_AMT_B;

    //--- 
    this.dataHeader.DUTY_AMT_B = this.dataHeader.INCOME_TAX + this.dataHeader.EXCISE_TAX + this.dataHeader.INTERIOR_TAX + this.dataHeader.RACK_DUTY + this.dataHeader.OTHER_TAX;

  }

  public Calculation() {


    if(!this.dataHeader.ARRIVAL_DATE){
      this.modal.warning("Arrival Date must be entered",this.viewRef)
      return;
    }

    if (this.dataHeader.C_AUTO_CAL_DUTY) {
      this.dataHeader.AUTO_CAL_DUTY = 'Y';
    } else {
      this.dataHeader.AUTO_CAL_DUTY = 'N';
    }

    //--- Set amount ----
    this.SetAmount();

    this.http.get("AC", "SNPE007_Validate", this.INVOICE_NO, this.INVOICE_DATE, this.VENDOR_CODE)
      .subscribe(result => {
        if (result == 'DONE') {
          this.http.post("AC", "SNPE007_BTM_CAL", JSON.stringify(this.dataHeader))
            .subscribe(result => {
              if (result != 'Error') {
                this.dataSummary = result.Table[0];
                this.GetInvData(1);
                this.IsCalculate = true;
                this.modal.info("Calculate operation successfully", this.viewRef);
              } else {
                this.modal.warning("Found an error, please contract support team", this.viewRef);
              }

            })

        } else if (result == 'NO DATA FOR CALCULATE') {
          this.modal.warning("No received part for calculation", this.viewRef);

        } else {
          this.modal.warning(result, this.viewRef);
        }
      })


  }

  public Confirm() {

    this.SetAmount();

    this.modal.confirm("Are you sure to confirm?", this.viewRef,
      () => {

        this.http.post("AC", "SNPE007_Confirm", JSON.stringify(this.dataHeader))
          .subscribe(result => {
            if (result == "DONE") {
              this.GetInvData(0);
              this.IsCalculate = false;
              this.modal.info("Transaction complete: applied and saved.", this.viewRef);
            } else {
              this.modal.warning("Found an error, please contract support team", this.viewRef);
            }
          }, (err) => {
            console.log(err, 'err')
            this.modal.warning("Found an error, please contract support team", this.viewRef);
          })


      }, () => { })

  }

  public SendByChanged() {

  }

  public GetpartList() {

    this.http.get("AC", "SNPE007_GetPartExpList", this.INVOICE_NO, this.INVOICE_DATE, this.dataHeader.VENDOR_CODE)
      .subscribe(result => {
        if (result != 'Error') {
          this.dataPartList = result.Table;
        } else {
          this.modal.warning("Found an error, please contract support team", this.viewRef);
        }

      })

  }

  public SaveDetail() {

    this.modal.confirm("Do you want to save changed you have made?", this.viewRef,
      () => {
        this.z_SaveDetail();
      }, () => { })

  }

  private z_SaveDetail() {

    var sendData: any = [];
    var i: number = 0;

    this.dataPartList.forEach((value) => {

      if (value.EXCISE_TAX != value.EXCISE_TAX_OLD || value.INTERIOR_TAX != value.INTERIOR_TAX ) {
        sendData[i] = {};
        sendData[i].INVOICE_NO = value.INVOICE_NO;
        sendData[i].VENDOR_CODE = value.VENDOR_CODE;

        sendData[i].ACCEPT_PART_NO = value.ACCEPT_PART_NO;
        sendData[i].EXCISE_TAX = value.EXCISE_TAX;
        sendData[i].INTERIOR_TAX = value.INTERIOR_TAX;

        sendData[i].INVOICE_DATE = this.dataHeader.INVOICE_DATE;
        sendData[i].INVOICE_PROCESS = this.dataHeader.INVOICE_PROCESS;
        sendData[i].LAST_UPD_PGM = 'SNPE007';
        i = i + 1;
      }

    });

    if (i == 0) {
      this.modal.info("There is no record change", this.viewRef)
      return;
    }

    this.http.post("AC", "SNPE007_EditPartDetail", JSON.stringify(sendData))
      .subscribe(result => {
        if (result != "Error") {
          this.GetInvData(1);
          this.modal.info("Transaction complete: applied and saved.", this.viewRef);
        }
      }, (err) => {
        console.log(err, 'err')
      })

  }

  AdjustTax(){
    this.modal.info("This function will be effect only (Income Tax , Excise Tax , Interior Tax)",this.viewRef,this.z_AdjustTax)
  }
  

  z_AdjustTax = () =>{

    this.http.post("AC","SNPE007_ADJ_TAX",this.dataHeader)
    .subscribe(res =>{
      this.modal.info("Transaction complete: applied and saved.",this.viewRef);
      this.dataSummary.SUM_DUTY_AMT_B = res.Table[0].SUM_DUTY_AMT_B
      this.dataSummary.SUM_TOT_NET_AMT = res.Table[0].SUM_TOT_NET_AMT
      this.GetInvData(1);
    })

  }
  
  PartList_ExciseChange(data){
    data.INTERIOR_TAX = data.EXCISE_TAX == 0 ? 0 : data.EXCISE_TAX / 10
    data.DUTY_AMT_B =   data.TMP_DUTY_AMT_B + data.EXCISE_TAX + data.INTERIOR_TAX
    data.TOT_AMT_ALL =  data.TMP_TOT_AMT_ALL + data.DUTY_AMT_B 
    data.UNIT        =  this.global.Round(data.TOT_AMT_ALL / data.TOT_QTY,2)
    this.dataPartList = this.dataPartList.slice();
  }

  PartList_InteriorChange(data){
    data.DUTY_AMT_B =   data.TMP_DUTY_AMT_B + data.INTERIOR_TAX
    data.TOT_AMT_ALL =  data.TMP_TOT_AMT_ALL + data.DUTY_AMT_B 
    data.UNIT        =  this.global.Round(data.TOT_AMT_ALL / data.TOT_QTY,2)
    this.dataPartList = this.dataPartList.slice();
  }


  public Report() {

    this.global.GoToReport("PMS_RPT_ACC_SNPE007",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_INVOICE_NO: this.INVOICE_NO,
        P_INVOICE_DATE: this.INVOICE_DATE,
        P_VENDOR_CODE: this.VENDOR_CODE
      }
    );

  }

}
