import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snpe017',
  templateUrl: './snpe017.component.html',
  styleUrls: ['./snpe017.component.css']
})



export class SNPE017Component implements OnInit {

  public params = {
    PART_NO: null,
    PART_NAME_EN: null,
    PART_NAME_TH: null,
    DUTY_RATE: null,
    NEW_DUTY_RATE: null,
    TARIFF_CODE: null,
    NEW_TARIFF_CODE: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    LAST_UPD_NAME: null
  }

  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public selectedStatus: number;  

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "AC",
    SourceMethodName: "SNPE017_GetPartList",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public SetSelectedPartNo(value: any) {
    this.params.PART_NO = value.PART_NO;
    this.params.PART_NAME_EN = value.PART_NAME_EN;
    this.params.PART_NAME_TH = value.PART_NAME_TH;
    this.params.TARIFF_CODE = value.TARIFF_CODE;
    this.params.DUTY_RATE = value.DUTY_RATE;
    this.params.LAST_UPD_NAME = value.LAST_UPD_NAME;
    this.params.LAST_UPD_DATE = value.LAST_UPD_DATE;
  }

  public lookupTariffCodeConfig: any = {
    ColName: "TARIFF_CODE",
    PlaceholderText: "Select Tariff Code",
    SourceController: "AC",
    SourceMethodName: "GetTariffCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }

  public SetSelectedTariffCode(value: any) {
    this.params.NEW_TARIFF_CODE = value.TARIFF_CODE;
    if (value.DUTY_RATE) {
      this.params.NEW_DUTY_RATE = parseFloat(value.DUTY_RATE).toFixed(4)
    }
    else {
      this.params.NEW_DUTY_RATE = null;
    }
  }

  ngOnInit() {
    this.selectedStatus = 1;
  }

  clearData() {
    this.params = {
      PART_NO: null,
      PART_NAME_EN: null,
      PART_NAME_TH: null,
      DUTY_RATE: null,
      NEW_DUTY_RATE: null,
      TARIFF_CODE: null,
      NEW_TARIFF_CODE: null,
      LAST_UPD_BY: null,
      LAST_UPD_DATE: null,
      LAST_UPD_NAME: null
    }
  }

  ConfirmSave() {
    if (!this.params.NEW_TARIFF_CODE) {
      this.params.NEW_TARIFF_CODE = this.params.TARIFF_CODE
    }
    if ((this.params.NEW_DUTY_RATE == '' || this.params.NEW_DUTY_RATE == null) && this.params.NEW_DUTY_RATE != 0) {
      this.params.NEW_DUTY_RATE = this.params.DUTY_RATE
    }
    if ((this.params.NEW_DUTY_RATE == 0 ||this.params.NEW_DUTY_RATE) && this.params.NEW_TARIFF_CODE) {
      if (this.selectedStatus == 1) {
        this.modal.confirm('Do you want to update on this data to Part Master?', this.viewref, this.SavePart)
      }
      else if (this.selectedStatus == 2) {
        this.modal.confirm('Do you want to update on this data to Part Master & Indent File?', this.viewref, this.SaveAll)
        console.log(this.params)
      }
    }
  }

  SavePart = () => {
    this.Http.post('AC', 'SNPE017_Save', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Done.', this.viewref);
          this.params.DUTY_RATE = this.params.NEW_DUTY_RATE;
          this.params.TARIFF_CODE = this.params.NEW_TARIFF_CODE;
          this.params.NEW_DUTY_RATE = null;
          this.params.NEW_TARIFF_CODE = null;
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  SaveAll = () => {
    this.Http.post('AC', 'SNPE017_SaveAll', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Done.', this.viewref);
          this.params.DUTY_RATE = this.params.NEW_DUTY_RATE;
          this.params.TARIFF_CODE = this.params.NEW_TARIFF_CODE;
          this.params.NEW_DUTY_RATE = null;
          this.params.NEW_TARIFF_CODE = null;
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }
}
