import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';


@Component({
  selector: 'snse015',
  templateUrl: './SNSE015.component.html',
  styleUrls: ['./SNSE015.component.css']
})



export class SNSE015Component implements OnInit {

  constructor(
    private Http: HttpService,
    //private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogReport", { static: false }) dialogReport: any;

  public params = {
    CUSTOMER_CODE: null,
    CUSTOMER_NAME: null,
    ORDER_NO: null,
    ORDER_CLASS: null,
    DSP_ORDER_CLASS: null,
    ORDER_DATE: null,
    BO_FLAG: null,
    LOCK_CUSTOMER: null,
    LAST_UPD_DATE: null,
    LAST_UPD_NAME: null
  }

  public params2: any = {};

  public TableData: any = [];

  public DataIsSelected: any;
  public selection = new SelectionModel<any>(true, []);

  ngOnInit() {
  }

  //-------------For Report---------------

  public SelectedCustomerFrom(event) {
    this.params2.CUSTOMER_CODE_FROM = event.CUSTOMER_CODE
    this.params2.ORDER_NO_FROM = null;
  }

  public SelectedCustomerTo(event) {
    this.params2.CUSTOMER_CODE_TO = event.CUSTOMER_CODE
    this.params2.ORDER_NO_TO = null;
  }

  public SelectedOrderNoFrom(event) {
    this.params2.ORDER_NO_FROM = event.ORDER_NO;
  }

  public SelectedOrderNoTo(event) {
    this.params2.ORDER_NO_TO = event.ORDER_NO;
  }

  //--------------------------------------




  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetCustomerCode",
    NoOfShowRecords: 10000,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.DSP_ORDER_CLASS = null;
    this.params.ORDER_NO = null;
    this.params.ORDER_CLASS = null;
    this.params.ORDER_DATE = null;
    this.params.BO_FLAG = null;
    this.params.LOCK_CUSTOMER = null;
    this.params.LAST_UPD_DATE = null;
    this.params.LAST_UPD_NAME = null;

    this.params2.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE
    this.params2.CUSTOMER_CODE_TO = values.CUSTOMER_CODE

  }

  public lookupOrderNoConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.DSP_ORDER_CLASS = values.DSP_ORDER_CLASS;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.BO_FLAG = values.BO_FLAG;
    this.params.LOCK_CUSTOMER = values.LOCK_CUSTOMER;
    this.params.LAST_UPD_DATE = values.LAST_UPD_DATE;
    this.params.LAST_UPD_NAME = values.LAST_UPD_NAME;

    this.params2.ORDER_NO_FROM = values.ORDER_NO;
    this.params2.ORDER_NO_TO = values.ORDER_NO;

    this.Search();
  }


  public lookupOrderNoRptConfig: any = {
    ColName: "ORDER_NO_TEXT",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE015_GetOrderNoRpt",
    NoOfShowRecords: 100,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }


  Search = () => {
    this.TableData = [];
    this.Http.post('SL', 'SNSE015_getData', this.params)
      .subscribe(res => {
        this.TableData = res.Table;
      })
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.TableData.length;
    return numSelected === numRows;
  }

  Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.TableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.TableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.TableData.map(x => {
        this.DataIsSelected.push(x);
      })
    }
  }

  CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
    }
  }

  ConfirmAllowcate() {
    this.modal.confirm('Do you want to allocate this order?', this.viewref, this.Allocate)
  }

  Allocate = () => {
    this.Http.post('SL', 'SNSE015_AllocateOrder', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info("Allocate Order Completed.", this.viewref);
          this.Search();

        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }


  openReport() {
    this.dialogReport.OpenDialog();
  }

  CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    if (this.params2.CUSTOMER_CODE_FROM && this.params2.CUSTOMER_CODE_TO && this.params2.ORDER_NO_FROM && this.params2.ORDER_NO_TO) {
      this.global.GoToReport("PMS_RPT_SALES_SNSE015R", {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUST_CODE_FROM: this.params2.CUSTOMER_CODE_FROM,
        P_CUST_CODE_TO: this.params2.CUSTOMER_CODE_TO,
        P_ORDER_NO_FROM: this.params2.ORDER_NO_FROM,
        P_ORDER_NO_TO: this.params2.ORDER_NO_TO
      })
    }
    else {
      this.modal.warning("Please fill Customer Code Or Order No.", this.viewref);
    }
  }
}
