import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snsq009',
  templateUrl: './snsq009.component.html',
  styleUrls: ['./snsq009.component.css']
})

export class SNSQ009Component implements OnInit {

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute
  ) { 

  }

  public dataList: any;
  public formData: any = {};

  public lookupConfig: any = {
    ColName: "LOOKUP_PART_VALUE",
    PlaceholderText: "Select Accept Part",
    SourceController: "IC",
    SourceMethodName: "SNSQ009_GetAcceptPart",
    NoOfShowRecords: 50,
    MinLengthSearch: 5
  }

  ngOnInit() { }

  GetOrderStatusList(accept_part_no: string) {
    this.dataList = [];
    this.http.get("IC", "SNSQ009_Query", accept_part_no)
      .subscribe(result => {
        this.dataList = result.Table;
      })
  }

  SaveCancelOrder() {
    let cancelRec = this.dataList.filter(v => v.CANCEL_FLAG);

    if (cancelRec.length > 0) {
      this.modal.confirm("Are you sure to cancel selected row?", this.viewref,
        () => {
          this.http.post("IC", 'SNSQ009_SaveUpdate', cancelRec)
            .subscribe(result => {
              this.modal.info("Update completed.", this.viewref);
              this.GetOrderStatusList(this.formData.ACCEPT_PART_NO);
            }, (err) => {
              this.modal.error(err.message, this.viewref);
            })
        }, () => {
          return false;
        })

    } else {
      this.modal.error("There is no cancel record.", this.viewref);
      return;
    }

  }

  SetSelectedPart(value: any) {
    this.formData.ACCEPT_PART_NO = value.ACCEPT_PART_NO;
    this.formData.PART_NAME = value.PART_NAME_EN;

    this.GetOrderStatusList(this.formData.ACCEPT_PART_NO);
  }

  CheckCancelable(data: any) {
    return data.UPDATE_ALLOW_AUTH === 'Y';
  }

  TitleCancelable(data: any) {
    let returnMsg = "";

    if (data.UPDATE_ALLOW_AUTH === 'N') {
      returnMsg = returnMsg + ', Picking card issued.. contact PIC for this order'
    }

    return returnMsg.replace(/^[,]+|[,]+$/g, "");
  }

  ClearSearch() {
    this.formData = {};
  }

}



