import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';


@Component({
  selector: 'snse023_001',
  templateUrl: './SNSQ023_001.component.html',
  styleUrls: ['./SNSQ023_001.component.css']
})


export class SNSQ023_001Component implements OnInit {

  public params = {
    FROM_DATE: null,
    TO_DATE: null,
    CUSTOMER_CODE: null,
    CUSTOMER_NAME: null,
    ORDER_NO: null,
    ORDER_PART_NO: null
  }

  public tableData: any;

  public formData = {
    CNT_REC: 0,
    CNT_FIRST_ORDER: 0,
    AVG_LT_ALLOCATED_PICK: '0',
    CNT_FIRST_ALLOCATE_LINE: 0,
    AVG_LT_PICK_INVOICE: '0',
    V_FILL_RATE: '0'
  }

  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  ngOnInit() {
    var date = new Date();
    this.params.FROM_DATE = new Date(date.getFullYear(), date.getMonth(), 1, 7);
    this.params.TO_DATE = new Date();
  }

  InitData() {
    this.formData.CNT_REC = 0;
    this.formData.CNT_FIRST_ORDER = 0;
    this.formData.AVG_LT_ALLOCATED_PICK = '0';
    this.formData.CNT_FIRST_ALLOCATE_LINE = 0;
    this.formData.AVG_LT_PICK_INVOICE = '0';
    this.formData.V_FILL_RATE = '0';
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSQ023_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSQ023_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Order Part No",
    SourceController: "SL",
    SourceMethodName: "SNSQ023_GetOrderPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCode(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = value.CUST_NAME_EN;
    this.params.ORDER_NO = null;
    this.params.ORDER_PART_NO = null;
  }

  public SetSelectedOrderNo(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE
    this.params.CUSTOMER_NAME = value.CUST_NAME_EN;
    this.params.ORDER_NO = value.ORDER_NO;
    this.params.ORDER_PART_NO = null;
  }

  public SetSelectedOrderPartNo(value: any) {
    this.params.CUSTOMER_CODE = value.CUSTOMER_CODE
    this.params.CUSTOMER_NAME = value.CUST_NAME_EN;
    this.params.ORDER_NO = value.ORDER_NO
    this.params.ORDER_PART_NO = value.ORDER_PART_NO;
  }

  Search() {
    this.tableData = null;
    this.InitData();
    this.Http.post("SL", "SNSQ023_GetData", this.params)
      .subscribe(res => {
        this.tableData = res.Table;
        console.log(this.tableData[0])
        if (this.tableData) {
          this.formData.CNT_REC = this.tableData.length;
          this.formData.CNT_FIRST_ORDER = this.tableData[0].CNT_FIRST_ORDER;
          this.formData.CNT_FIRST_ALLOCATE_LINE = this.tableData[0].CNT_FIRST_ALLOCATE_LINE;
          this.formData.AVG_LT_ALLOCATED_PICK = this.tableData[0].AVG_LT_ALLOCATED_PICK;
          this.formData.AVG_LT_PICK_INVOICE = this.tableData[0].AVG_LT_PICK_INVOICE;
          this.formData.V_FILL_RATE = this.tableData[0].FILL_RATE;

        }
      })
  }

  ExportExcel() {
    if (this.formData.CNT_REC > 0) {
      this.Http.Download('SL', 'SNSQ023_Export', JSON.stringify(this.tableData))
        .subscribe(res => {
          if (res) {
            this.WriteContents(res)
          } else {
            this.modal.error('Download not complete', this.viewref)
          }
        })
    }
    else {
      this.modal.error('Cannot download file from empty data!', this.viewref)
    }
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSQ023.csv";
    a.click();
  }
}
