import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import { min } from 'rxjs/operators';

@Component({
  selector: 'snsq038',
  templateUrl: './SNSQ038.component.html',
  styleUrls: ['./SNSQ038.component.css']
})



export class SNSQ038Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef,
    private global : Globals
  ) { }
  @ViewChild("dialog",{static: false}) dialog : any;
  public ParamSearch :any ={};
  public Params :any ={};
  public categoryList: any = [];
  public tabledata : any = [];
  public isAdd : boolean = false;
  public CategoryControl = new FormControl('',[Validators.required])

  public ConfigSupplier: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Supplier Code",
    SourceController: "TI",
    SourceMethodName: "SNSQ030_GetSupplier",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: false
  }


  public ConfigPart: any = {
    ColName: "LOOKUP",
    ColValue: "",
    PlaceholderText: "Select Part",
    SourceController: "TI",
    SourceMethodName: "SNSQ038_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: false,
  }


  public tblFooter: any = [
    {
      fieldName: "PART_NUMBER",
      value: null,
      show: true
    },]


  ngOnInit() {
    this.ParamSearch.RECIEVE_TYPE = 'ALL'
    this.ParamSearch.DATE_FROM = this.FirstDateOfMonth()
    this.ParamSearch.DATE_TO = new Date();


  }

  Search(){
    this.tabledata = []
    this.http.post("TI","SNSQ038_GetData",this.ParamSearch)
    .subscribe(res =>{
      if(res.Table.length > 0 ){
        res.Table.map((x,i) => {
          x.ROW_SEQ = i + 1
        })
        this.tblFooter[0].value = "Count Item : " + res.Table.length.toLocaleString()
        this.tabledata = res.Table
      }else{
        this.tabledata = res.Table
      }
          
    })
  }


  ExportExcel(){
    if(this.tabledata.length == 0){
      this.modal.warning("No data for export!",this.viewref);
    }else{

      this.http.Download("TI","SNSQ038_Download",this.tabledata)
      .subscribe(res =>{
        this.modal.info("Export Complete",this.viewref);
        this.writeContents(res)
      })


    }
  }

  writeContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSQ038_FILE" + '-' + this.FormateDate() + '' + ".csv";
    a.click();
  }


  FormateDate() {

    let d = new Date()
    let day = d.getDate();
    let newDay = day.toString().length < 2 ? 0 + '' + day.toString() : day.toString();
    let m = d.getMonth() + 1;
    let newMonth = m.toString().length < 2 ? 0 + '' + m.toString() : m.toString();
    let y = d.getFullYear();
    let hours = d.getHours();
    let minute = d.getMinutes();
    let seconds = d.getSeconds();
    return y + '' + newMonth + '' + newDay + '_' + hours + ':' + minute + ':' + seconds;
}

  FirstDateOfMonth(){
  var date = new Date();
  var firstDay = new Date(date.getFullYear(), date.getMonth(), 1);
  firstDay.setDate(firstDay.getDate() + 1);
  return firstDay;
}

}
