import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { ModalService } from '../../../core/modal.service';
import { FormControl, Validators } from '@angular/forms';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { HttpClient } from '@angular/common/http';
import { Globals } from '../../../core/global';

@Component({
  selector: 'snm025p',
  templateUrl: './SNM025P.component.html',
  styleUrls: ['./SNM025P.component.css']
})



export class SNM025PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private httpC: HttpClient,
    private global: Globals
  ) { }
  @ViewChild("dialogMain", { static: false }) dialogMain: any;
  @ViewChild("dialog", { static: false }) dialog: any;
  public data: any = [];
  public VENDOR_CODE: any = null;
  public VENDOR_NAME: any;
  public CategoryLits: any = [];
  public BranchList: any = [];
  public opened: boolean;
  public tableData: any = [];
  public FrmTitle: any;
  public ConfigRack: any = {
    ColName: "RACK_CODE",
    ColValue: "RACK_CODE",
    PlaceholderText: "Select Rate",
    SourceController: "WH",
    SourceMethodName: "SNM025P_GetRack",
    NoOfShowRecords: 30,
    MinLengthSearch: 1,
    UpperCase: false
  }
 
  public params = {
    RACK_CODE: null,
    ITEM_NO: null 
  }
  GetRackS(code) {
    this.params.RACK_CODE = code;
  }
 

  public RackData: any = {
    COMPANY_CODE: null,
    RACK_CODE: null,
    ITEM_NO: null,
    DIMENSION_MAX: null,
    DIMENSION_MID: null,
    DIMENSION_MIN: null,
    VOLUMN_MAX: null,
    VOLUMN_MIN: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    LAST_UPD_PGM: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    ATTRIBUTE1: null,
    ATTRIBUTE2: null,
    ATTRIBUTE3: null,
    ATTRIBUTE4: null,
    ATTRIBUTE5: null,
    LAST_IP_ADDR: null,
    LAST_UPD_NAME:null
  }


  public valid: boolean = false;
  public TableData: any = [];
  public MainDatatable: any;
  public CategoryList: any = [];


  ngOnInit() {
    this.InitData();
  }

  SearchForAc(){
    this.http.get('WH', 'SNM025P_GetRack_List', this.params.RACK_CODE  )
      .subscribe(res => {
        this.MainDatatable = res.Table;
      })
  }
  deleteRow(data) {
    this.RackData.RACK_CODE = data.RACK_CODE;
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.ConfirmDeleteRow);
  }
  ConfirmDeleteRow = () => {
    this.RackData.LAST_IP_ADDR = this.global.GetTokenDetail("ssIPAddress");
    this.http.post('WH', 'SNM025P_delete_Rack', this.RackData)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.SearchForAc();
        }
      });

  }
  EditRow(data) {
    this.InitData();
    this.FrmTitle = "Edit Rack";
    this.http.get("WH", "SNM025P_GetRack_Info", data.RACK_CODE)
      .subscribe(result => {
        if (result.Table.length > 0) {
          this.RackData = result.Table[0];
          this.RackData.CREATE_DATE = new Date();
          this.RackData.LAST_UPD_DATE = new Date();
          this.RackData.LAST_UPD_NAME = this.global.GetTokenDetail("ssNameEN");
          this.dialogMain.OpenDialog();
        }
      });
  }
  GetRackDate(RackCode) {
    this.RackData.RACK_CODE = RackCode;
    this.http.get("WH", "SNM025P_GetRack_Info", RackCode)
      .subscribe(result => {
        this.RackData = result.Table[0];
        console.log(this.RackData);
      })
  }

  SaveAdd() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)
  }

  ConfirmSaveAdd = () => {
    this.RackData.LAST_IP_ADDR = this.global.GetTokenDetail("ssIPAddress");
    this.http.post('WH', 'SNM025P_Rack_Save', this.RackData)
      .subscribe(res => {
        console.log(res)
        if (res.Table[0].STATUS == 'DONE') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  CancelAdd() {
    this.InitData();
    this.dialogMain.Close();
  }
  InitData() {
    this.FrmTitle = "New Rack";
    this.RackData = {};
    this.RackData.CREATE_DATE = new Date();
    this.RackData.LAST_UPD_DATE = new Date();
    this.RackData.LAST_UPD_NAME = this.auth.getDetail().ssNameEN;
  }
  openDialog() {
    this.tableData = [];
    this.http.get("WH", "SNM025P_GetRack_Info", "@@@")
      .subscribe(result => {
        this.tableData = result.Table;
        this.dialog.title = "Rack Size";
        this.dialog.OpenDialog()
      });
  }
  ClickRow(event) {
 
  }
  editBtnClick(data) {
    this.GetRackDate(data.RACK_CODE) 
    this.dialog.Close();
  }
  Cancel() {
    this.dialog.Close();
  }
}

